pub struct Engine { /* private fields */ }Expand description
The template engine
Implementations
Sourceimpl Engine
impl Engine
Sourcepub fn strict() -> Self
pub fn strict() -> Self
Create a strict mode engine (Helm-compatible, recommended)
Uses UndefinedBehavior::Chainable which allows accessing properties
on undefined values, returning undefined instead of error.
Sourcepub fn lenient() -> Self
pub fn lenient() -> Self
Create a lenient mode engine
Uses UndefinedBehavior::Lenient which returns empty strings
for undefined values.
Sourcepub fn builder() -> EngineBuilder
pub fn builder() -> EngineBuilder
Create a builder for more configuration options
Sourcepub fn render_string(
&self,
template: &str,
context: &TemplateContext,
template_name: &str,
) -> Result<String>
pub fn render_string( &self, template: &str, context: &TemplateContext, template_name: &str, ) -> Result<String>
Render a single template string
Sourcepub fn render_pack(
&self,
pack: &LoadedPack,
context: &TemplateContext,
) -> Result<RenderResult>
pub fn render_pack( &self, pack: &LoadedPack, context: &TemplateContext, ) -> Result<RenderResult>
Render all templates in a pack
This is a convenience wrapper around render_pack_collect_errors that
returns the first error encountered, suitable for most use cases.
Sourcepub fn render_pack_collect_errors(
&self,
pack: &LoadedPack,
context: &TemplateContext,
) -> RenderResultWithReport
pub fn render_pack_collect_errors( &self, pack: &LoadedPack, context: &TemplateContext, ) -> RenderResultWithReport
Render all templates in a pack, collecting all errors instead of stopping at the first
Unlike render_pack, this method continues after errors and returns
a comprehensive report of all issues found.