Module pack_renderer

Module pack_renderer 

Pack renderer with subchart support

This module provides PackRenderer, which orchestrates the rendering of a pack and all its subcharts with proper value scoping.

Structs

PackRenderResult
Result of rendering a pack (with or without subcharts)
PackRenderResultWithReport
Result type that includes discovery info and error report
PackRenderer
Orchestrates rendering of a pack and its subcharts
PackRendererBuilder
Builder for PackRenderer